@@ -1,12 +1,41 @@
+# -*- coding: utf-8 -*-
+"""
+This module contains utilities added by billiard, to keep
+"non-core" functionality out of ``.util``."""
 from __future__ import absolute_import
 
 import signal
 import sys
 
 from time import time
+import pickle as pypickle
+try:
+    import cPickle as cpickle
+except ImportError:  # pragma: no cover
+    cpickle = None   # noqa
 
 from .exceptions import RestartFreqExceeded
 
+if sys.version_info < (2, 6):  # pragma: no cover
+    # cPickle does not use absolute_imports
+    pickle = pypickle
+    pickle_load = pypickle.load
+    pickle_loads = pypickle.loads
+else:
+    pickle = cpickle or pypickle
+    pickle_load = pickle.load
+    pickle_loads = pickle.loads
+
+# cPickle.loads does not support buffer() objects,
+# but we can just create a StringIO and use load.
+if sys.version_info[0] == 3:
+    from io import BytesIO
+else:
+    try:
+        from cStringIO import StringIO as BytesIO  # noqa
+    except ImportError:
+        from StringIO import StringIO as BytesIO  # noqa
+
 TERMSIGS = (
     'SIGHUP',
     'SIGQUIT',
@@ -30,6 +59,11 @@ TERMSIGS = (
 )
 
 
+def pickle_loads(s, load=pickle_load):
+    # used to support buffer objects
+    return load(BytesIO(s))
+
+
 def _shutdown_cleanup(signum, frame):
     sys.exit(-(256 - signum))
 
