@@ -17,7 +17,6 @@ from __future__ import with_statement
 import collections
 import errno
 import itertools
-import logging
 import os
 import platform
 import signal
@@ -163,15 +162,6 @@ class LaxBoundedSemaphore(_Semaphore):
                 if self._value < self._initial_value:
                     self._value += 1
                     cond.notify_all()
-                    if __debug__:
-                        self._note(
-                            "%s.release: success, value=%s", self, self._value,
-                        )
-                else:
-                    if __debug__:
-                        self._note(
-                            "%s.release: success, value=%s (unchanged)" % (
-                                self, self._value))
 
         def clear(self):
             while self._value < self._initial_value:
@@ -184,14 +174,6 @@ class LaxBoundedSemaphore(_Semaphore):
                 if self._Semaphore__value < self._initial_value:
                     self._Semaphore__value += 1
                     cond.notifyAll()
-                    if __debug__:
-                        self._note("%s.release: success, value=%s",
-                                   self, self._Semaphore__value)
-                else:
-                    if __debug__:
-                        self._note(
-                            "%s.release: success, value=%s (unchanged)" % (
-                                self, self._Semaphore__value))
 
         def clear(self):  # noqa
             while self._Semaphore__value < self._initial_value:
